==> libbpp-seq_2.1.0.orig.tar.gz: bpp-seq-2.1.0/src/Bpp/Seq/Container/SiteContainerExceptions.cpp <==
//
// File SiteContainerExceptions.cpp
// Author: Julien Dutheil
// Created on: mer mar 31 2004
// 

/*
Copyright or © or Copr. CNRS, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "SiteContainerExceptions.h"

using namespace bpp;
using namespace std;

/*******************************************************************************
 *                       Site containers exceptions                            *
 *******************************************************************************/

SiteNotFoundException::SiteNotFoundException(const char *   text, const char * sId) :
	Exception("SequenceNotFoundException: " + string(text) + "(" + sId + ")"),
	id(sId) {};

SiteNotFoundException::SiteNotFoundException(const string & text, const string & sId) :
	Exception("SequenceNotFoundException: " + text + "(" + sId + ")"),
	id(sId) {};

SiteNotFoundException::~SiteNotFoundException() throw() {};

const string SiteNotFoundException::getSiteId() const { return id; }

==> libbpp-seq_2.4.1.orig.tar.gz: bpp-seq-2.4.1/src/Bpp/Seq/Container/SiteContainerExceptions.cpp <==
//
// File SiteContainerExceptions.cpp
// Author: Julien Dutheil
// Created on: mer mar 31 2004
// 

/*
Copyright or © or Copr. CNRS, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "SiteContainerExceptions.h"

using namespace bpp;
using namespace std;

/*******************************************************************************
 *                       Site containers exceptions                            *
 *******************************************************************************/

SiteNotFoundException::SiteNotFoundException(const char *   text, const char * sId) :
	Exception("SequenceNotFoundException: " + string(text) + "(" + sId + ")"),
	id(sId) {};

SiteNotFoundException::SiteNotFoundException(const string & text, const string & sId) :
	Exception("SequenceNotFoundException: " + text + "(" + sId + ")"),
	id(sId) {};

SiteNotFoundException::~SiteNotFoundException() {};

const string SiteNotFoundException::getSiteId() const { return id; }
